embassy-stm32

Crates

git

Versions

stm32h745ii-cm4

Flavors

QUADSPI

Struct QUADSPI 

pub struct QUADSPI { /* private fields */ }
QUADSPI peripheral

Implementations

Source

impl QUADSPI

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.